@@ -164,6 +164,8 @@ def lookup_alfred_configuration_path() -> path:
         if alfred_configuration_path is not None:
             break
 
+    logging.debug(f"alfred configuration file : {alfred_configuration_path}")
+
     return alfred_configuration_path
 
 
@@ -172,8 +174,9 @@ def lookup_alfred_configuration() -> dict:
 
     with io.open(alfred_configuration_path,  encoding="utf8") as file:
         alfred_configuration = yaml.load(file, Loader=SafeLoader)
-        for index, plugin in enumerate(alfred_configuration["plugins"]):
+        for plugin in alfred_configuration["plugins"]:
             plugin['path'] =  os.path.realpath(os.path.join(alfred_configuration_path, '..', plugin['path']))
+            logging.debug(f"alfred plugin : {plugin}")
 
         return alfred_configuration
 
